@@ -30,8 +30,7 @@ module Slim
   # @api private
   class OutputProtector < Filter
     def call(exp)
-      @protect = []
-      @collected = ''
+      @protect, @collected, @tag = [], '', "%#{object_id.abs.to_s(36)}%"
       super(exp)
       @collected
     end
@@ -42,16 +41,16 @@ module Slim
     end
 
     def on_slim_output(escape, text, content)
-      @collected << "pro#{@protect.size}tect"
+      @collected << @tag
       @protect << [:slim, :output, escape, text, content]
       nil
     end
 
     def unprotect(text)
       block = [:multi]
-      while text =~ /pro(\d+)tect/
+      while text =~ /#{@tag}/
         block << [:static, $`]
-        block << @protect[$1.to_i]
+        block << @protect.shift
         text = $'
       end
       block << [:static, text]
@@ -63,25 +62,29 @@ module Slim
   class Embedded < Filter
     @engines = {}
 
-    # Register embedded engine
-    #
-    # @param [String] name Name of the engine
-    # @param [Class]  klass Engine class
-    # @param option_filter List of options to pass to engine.
-    #                      Last argument can be default option hash.
-    def self.register(name, klass, *option_filter)
-      name = name.to_sym
-      local_options = option_filter.last.respond_to?(:to_hash) ? option_filter.pop.to_hash : {}
-      define_options(name, *option_filter)
-      klass.define_options(name)
-      @engines[name.to_sym] = proc do |options|
-        klass.new({}.update(options).delete_if {|k,v| !option_filter.include?(k) && k != name }.update(local_options))
-      end
-    end
+    class << self
+      attr_reader :engines
 
-    def self.create(name, options)
-      constructor = @engines[name] || raise(Temple::FilterError, "Embedded engine #{name} not found")
-      constructor.call(options)
+      # Register embedded engine
+      #
+      # @param [String] name Name of the engine
+      # @param [Class]  klass Engine class
+      # @param option_filter List of options to pass to engine.
+      #                      Last argument can be default option hash.
+      def register(name, klass, *option_filter)
+        name = name.to_sym
+        local_options = option_filter.last.respond_to?(:to_hash) ? option_filter.pop.to_hash : {}
+        define_options(name, *option_filter)
+        klass.define_options(name)
+        engines[name.to_sym] = proc do |options|
+          klass.new({}.update(options).delete_if {|k,v| !option_filter.include?(k) && k != name }.update(local_options))
+        end
+      end
+
+      def create(name, options)
+        constructor = engines[name] || raise(Temple::FilterError, "Embedded engine #{name} not found")
+        constructor.call(options)
+      end
     end
 
     define_options :enable_engines, :disable_engines
@@ -109,7 +112,7 @@ module Slim
 
     def normalize_engine_list(list)
       raise(ArgumentError, "Option :enable_engines/:disable_engines must be String or Symbol list") unless !list || Array === list
-      list ? list.map {|s| s.to_sym } : list
+      list && list.map(&:to_sym)
     end
 
     class Engine < Filter
@@ -133,10 +136,7 @@ module Slim
         tilt_options = options[engine.to_sym] || {}
         [:multi, tilt_render(tilt_engine, tilt_options, collect_text(body)), collect_newlines(body)]
       end
-    end
 
-    # Tilt-based static template (evaluated at compile-time)
-    class StaticTiltEngine < TiltEngine
       protected
 
       def tilt_render(tilt_engine, tilt_options, text)
@@ -152,8 +152,8 @@ module Slim
 
       def tilt_render(tilt_engine, tilt_options, text)
         text = tilt_engine.new(tilt_options.merge(
-          :style => options[:pretty] ? :expanded : :compressed,
-          :cache => false)) { text }.render
+          style: options[:pretty] ? :expanded : :compressed,
+          cache: false)) { text }.render
         text.chomp!
         [:static, text]
       end
@@ -226,7 +226,7 @@ module Slim
     class JavaScriptEngine < TagEngine
       disable_option_validator!
 
-      set_default_options :tag => :script, :attributes => { :type => 'text/javascript' }
+      set_options tag: :script, attributes: {}
 
       def on_slim_embedded(engine, body)
         super(engine, [:html, :js, body])
@@ -251,11 +251,12 @@ module Slim
     register :org,        InterpolateTiltEngine
 
     # These engines are executed at compile time
-    register :coffee,     JavaScriptEngine, :engine => StaticTiltEngine
-    register :less,       TagEngine, :tag => :style,  :attributes => { :type => 'text/css' },         :engine => StaticTiltEngine
-    register :styl,       TagEngine, :tag => :style,  :attributes => { :type => 'text/css' },         :engine => StaticTiltEngine
-    register :sass,       TagEngine, :pretty, :tag => :style, :attributes => { :type => 'text/css' }, :engine => SassEngine
-    register :scss,       TagEngine, :pretty, :tag => :style, :attributes => { :type => 'text/css' }, :engine => SassEngine
+    register :coffee,     JavaScriptEngine, engine: TiltEngine
+    register :opal,       JavaScriptEngine, engine: TiltEngine
+    register :less,       TagEngine, tag: :style,  attributes: { type: 'text/css' },         engine: TiltEngine
+    register :styl,       TagEngine, tag: :style,  attributes: { type: 'text/css' },         engine: TiltEngine
+    register :sass,       TagEngine, :pretty, tag: :style, attributes: { type: 'text/css' }, engine: SassEngine
+    register :scss,       TagEngine, :pretty, tag: :style, attributes: { type: 'text/css' }, engine: SassEngine
 
     # These engines are precompiled, code is embedded
     register :erb,        ERBEngine
@@ -264,7 +265,7 @@ module Slim
 
     # Embedded javascript/css
     register :javascript, JavaScriptEngine
-    register :css,        TagEngine, :tag => :style,  :attributes => { :type => 'text/css' }
+    register :css,        TagEngine, tag: :style,  attributes: { type: 'text/css' }
 
     # Embedded ruby code
     register :ruby,       RubyEngine
