@@ -55,13 +55,18 @@ module Slim
         @tab_re = "\t"
         @tab = ' '
       end
-      @tag_shortcut, @attr_shortcut = {}, {}
+      @tag_shortcut, @attr_shortcut, @additional_attrs = {}, {}, {}
       options[:shortcut].each do |k,v|
-        raise ArgumentError, 'Shortcut requires :tag and/or :attr' unless (v[:attr] || v[:tag]) && (v.keys - [:attr, :tag]).empty?
+        raise ArgumentError, 'Shortcut requires :tag and/or :attr' unless (v[:attr] || v[:tag]) && (v.keys - [:attr, :tag, :additional_attrs]).empty?
         @tag_shortcut[k] = v[:tag] || options[:default_tag]
+        if v.include?(:attr) || v.include?(:additional_attrs)
+          raise ArgumentError, 'You can only use special characters for attribute shortcuts' if k =~ /(\p{Word}|-)/
+        end
         if v.include?(:attr)
           @attr_shortcut[k] = [v[:attr]].flatten
-          raise ArgumentError, 'You can only use special characters for attribute shortcuts' if k =~ /(\p{Word}|-)/
+        end
+        if v.include?(:additional_attrs)
+          @additional_attrs[k] = v[:additional_attrs]
         end
       end
       keys = Regexp.union @attr_shortcut.keys.sort_by {|k| -k.size }
@@ -221,13 +226,13 @@ module Slim
         # Found an output block.
         # We expect the line to be broken or the next line to be indented.
         @line = $'
-        trailing_ws = $2.include?('>')
-        if $2.include?('\'')
+        trailing_ws = $2.include?('>'.freeze)
+        if $2.include?('\''.freeze)
           deprecated_syntax '=\' for trailing whitespace is deprecated in favor of =>'
           trailing_ws = true
         end
         block = [:multi]
-        @stacks.last << [:static, ' '] if $2.include?('<')
+        @stacks.last << [:static, ' '] if $2.include?('<'.freeze)
         @stacks.last << [:slim, :output, $1.empty?, parse_broken_line, block]
         @stacks.last << [:static, ' '] if trailing_ws
         @stacks << block
@@ -326,18 +331,23 @@ module Slim
         # because we don't want text interpolation in .class or #id shortcut
         syntax_error!('Illegal shortcut') unless shortcut = @attr_shortcut[$1]
         shortcut.each {|a| attributes << [:html, :attr, a, [:static, $2]] }
+        if additional_attr_pairs = @additional_attrs[$1]
+          additional_attr_pairs.each do |k,v|
+            attributes << [:html, :attr, k.to_s, [:static, v]]
+          end
+        end
         @line = $'
       end
 
       @line =~ /\A[<>']*/
       @line = $'
-      trailing_ws = $&.include?('>')
-      if $&.include?('\'')
+      trailing_ws = $&.include?('>'.freeze)
+      if $&.include?('\''.freeze)
         deprecated_syntax 'tag\' for trailing whitespace is deprecated in favor of tag>'
         trailing_ws = true
       end
 
-      leading_ws = $&.include?('<')
+      leading_ws = $&.include?('<'.freeze)
 
       parse_attributes(attributes)
 
@@ -366,13 +376,13 @@ module Slim
       when /\A\s*=(=?)(['<>]*)/
         # Handle output code
         @line = $'
-        trailing_ws2 = $2.include?('>')
-        if $2.include?('\'')
+        trailing_ws2 = $2.include?('>'.freeze)
+        if $2.include?('\''.freeze)
           deprecated_syntax '=\' for trailing whitespace is deprecated in favor of =>'
           trailing_ws2 = true
         end
         block = [:multi]
-        @stacks.last.insert(-2, [:static, ' ']) if !leading_ws && $2.include?('<')
+        @stacks.last.insert(-2, [:static, ' ']) if !leading_ws && $2.include?('<'.freeze)
         tag << [:slim, :output, $1 != '=', parse_broken_line, block]
         @stacks.last << [:static, ' '] if !trailing_ws && trailing_ws2
         @stacks << block
